# Web Application

`Tax-Brain` can be run via the Python API or the command line interface (CLI) as described in this document or through a GUI web application.  The online interface is hosted through [Compute Studio](https://compute.studio) and is available at [https://compute.studio/PSLmodels/Tax-Brain/](https://compute.studio/PSLmodels/Tax-Brain/).

On the web application, users are able to enter changes to individual income and payroll taxes.  The results page displays tabular and graphical output summarizing the revenue effects and distributional impacts of the simulated reform.  Further output is available for download.


[![Tax-Brain Web App Demo](http://i3.ytimg.com/vi/Zc_XEErfO5E/maxresdefault.jpg)](https://youtu.be/Zc_XEErfO5E "Tax-Brain Web App Demo")

This PSL Demo Day talk linked to in the image above shows how to use the Tax-Brain web application and interpret its output.